﻿
/*
 * ContactManager Class.
 *   Version: 1.0.0
 *   Desc: Stores a local shared object with address book data.
 *         Provides convenience methods for adding, removing and
 *         updating that data (people in the address book).
 */

 
 
/* =================
 * Class constructor
 * =================
 *   Desc: Creates the ContactManager object. Retrieves a local
 *         shared object (this.so) and initializes it if necessary.
 * =================
 */
function ContactManager () {
  // Get a reference to the local shared object.
  this.so = SharedObject.getLocal("addressBook");
  
  // If there's no contact container property yet, make one.
  if (typeof this.so.data.contacts == "undefined") {
    // Use a generic object as a hash.
    this.so.data.contacts = new Object();
  }  
  
  // If there's no existing id to use with contacts, assign a default.
  if (typeof this.so.data.uniqueid == "undefined") {
    this.so.data.uniqueid = 0;
  }
}


/* =================
 * Instance Methods
 * =================
 */
 
/*
 * Method: addContact()
 *   Desc: Creates a new Contact object and stores it in the shared
 *         object's "contacts" hash.
 *   Parameters:
 *     firstName      The new contact's first name, as a string.
 *     lastName       The new contact's last name, as a string.
 *     email          The new contact's email address, as a string.
 *     phone          The new contact's phone number, as a string.
 */

ContactManager.prototype.addContact = function (firstName, 
                                                lastName, 
												father,
												gender,
												birthday,
												place,
												number,
												address,
                                                email, 
                                                phone, 
                                                phonetype, 
                                                school, 
                                                grade,
												work,
												yes,
												no) {
                                                
  // Create a new contact object and store it in the "contacts" hash.
  this.so.data.contacts["record" + this.so.data.uniqueid] = 
                                    new Contact(firstName, 
                                                lastName, 
												father,
												gender,
												number,
												birthday,
												place,
												address,
                                                email, 
                                                phone, 
                                                phonetype, 
                                                school, 
                                                grade,
												work,
												yes,
												no,
                                                this.so.data.uniqueid);

  // Update the id for next time.
  this.so.data.uniqueid++;

  // Return a reference to the new contact.
  return this.so.data.contacts["record" + (this.so.data.uniqueid - 1)];
}


/*
 * Method: removeContact()
 *   Desc: Deletes the contact object specified by "id".
 *   Parameters:
 *     id             The identifier of the contact object to delete.
 */
ContactManager.prototype.removeContact = function (id) {
  delete this.so.data.contacts["record" + id];
}


/*
 * Method: updateContact()
 *   Desc: Deletes the contact object specified by "id".
 *   Parameters:
 *     id             The identifier of the contact object to update.
 *     firstName      The contact's first name, as a string.
 *     lastName       The contact's last name, as a string.
 *     email          The contact's email address, as a string.
 *     phone          The contact's phone number, as a string.
 *     phonetype      The type of phone number (home, work, cell)
 *     company        The person's place of business.
 *     comments       Arbitrary notes associated with the person.
 */
ContactManager.prototype.updateContact = function (id, 
                                                  firstName, 
                                                lastName, 
												father,
												gender,
												birthday,
												number,
												place,
												address,
                                                email, 
                                                phone, 
                                                phonetype, 
                                                school, 
                                                grade,
												work,
												yes,
												no) {
                                                   
  // Set the updated values on the contact.
  this.so.data.contacts["record" + id].firstName = firstName;
  this.so.data.contacts["record" + id].lastName = lastName;
  this.so.data.contacts["record" + id].father = father;
  this.so.data.contacts["record" + id].gender = gender;
  this.so.data.contacts["record" + id].birthday = birthday;
  this.so.data.contacts["record" + id].place = place;
  this.so.data.contacts["record" + id].address = address;
  this.so.data.contacts["record" + id].email = email;
  this.so.data.contacts["record" + id].number = number;
  this.so.data.contacts["record" + id].phone = phone;
  this.so.data.contacts["record" + id].phonetype = phonetype;
  this.so.data.contacts["record" + id].shcool = school;    
  this.so.data.contacts["record" + id].grade = grade;
  this.so.data.contacts["record" + id].work = work;
  this.so.data.contacts["record" + id].yes = yes;
  this.so.data.contacts["record" + id].no = no;
  
  // Note the time the contact was modified.
  this.so.data.contacts["record" + id].dateModified = new Date();
  
  // Return a reference to the updated contact.
  return this.so.data.contacts["record" + id];
}

